const initialState = {
    lines: [],
    lineSelected: null,
    linesDeleted: [],
    linesUpdate: [],
    showStatementLine: false
}

const state = {
    lines: initialState.lines,
    lineSelected: initialState.lineSelected,
    linesDeleted: initialState.linesDeleted,
    linesUpdate: initialState.linesUpdate,
    showStatementLine: initialState.showStatementLine
}

const getters = {
    statementLines(state) {
        return state.lines
    },
    linesDeleted(state) {
        return state.linesDeleted
    },
    linesUpdate(state) {
        return state.linesUpdate
    },
    showStatementLine(state) {
        return state.showStatementLine
    },
    lineSelected(state) {
        return  state.lineSelected;
    }
}

const mutations = {
    setLines(state, payload) {
        let data = []
        payload.forEach(item => {
            data.push({
                id: item.id,
                date: item.date,
                name: item.name,
                ref: item.ref,
                amount: item.amount,
                partnerId: item.partner.length === 0 ? '' : item.partner[0].id,
                partnerName: item.partner.length === 0 ? '' : item.partner[0].displayName,
                isDelete: false,
                isUpdate: false,
            })
        })
        state.lines = data
    },
    /*Show Modal Modify Line */
    setShowStatementLine( state, payload){
        state.showStatementLine = !!payload
    },
    /* */
    setLinesDeleted (state, payload) {
        state.lines.forEach(item => {
            if (item.id === payload.id ) {
                item.isDelete = payload.state
            }
        })

        if (!!payload.state) {
            let linesDeletedFound = state.linesDeleted.find(item => item === payload.id)
            if (!!linesDeletedFound) return
            state.linesDeleted = [payload.id, ...state.linesDeleted]
        }

        if (!payload.state) {
            let linesDeletedFound = state.linesDeleted.findIndex(item => item === payload.id)
            state.linesDeleted.splice(linesDeletedFound, 1)
        }
    },
    /* */
    setLinesUpdate (state, payload) {
        // state.lines.forEach(item => {
            // if (item.id === payload {
                // item.linesUpdate = payload
            // }
        // })

        if (!!payload) {
            let linesUpdateFound = state.linesUpdate.find(item => item === payload)
            if (!!linesUpdateFound) return
            state.linesUpdate = [payload, ...state.linesUpdate]
        }

        // if (!payload.state) {
        //     let linesDeletedFound = state.linesDeleted.findIndex(item => item === payload.id)
        //     state.linesDeleted.splice(linesDeletedFound, 1)
        // }
    },
    /* */
    setLineSelected(state, payload) {
        let selected = state.lines.find(item => item.id  === payload)
        state.lineSelected = !!selected ? selected : null
    },
}

const actions = {
    initLines({ commit, getters }) {
        if (!!getters.selectedStatement) {
            commit('setLines', getters.selectedStatement.line)
        }
    },
    resetLines({ commit }){
        commit('setLines', [])
    },
    selectLineSelected({ commit, dispatch },payload){
        commit('setLineSelected', payload)
        // dispatch('showStatementLineModify', payload)
    },
    addDeletedLine({ commit }, payload) {
        commit('setLinesDeleted', payload)
    },
    addUpdateLine({ commit }, payload){
        commit('setLinesUpdate', payload)
    },
    showStatementLineModify({ commit }, payload) {
        commit('setShowStatementLine', payload)
    },
    resetStatementLine({ commit }) {
        commit('setLines', [])
        commit('setLineSelected', null)
        commit('setLinesDeleted', [])
        commit('setLinesUpdate', [])
        commit('setShowStatementLine', [])
    }
}

export default{
    state,
    getters,
    mutations,
    actions
}
